@@ -35,13 +35,10 @@
 #' 
 #' 
 #' @aliases TimeStratPetersenDiagErrorWHSteel_fit 
-#' @param title A character string used for a title on reports and graphs
-#' @param prefix A character string used as the prefix for created files. All
-#' created graph files are of the form prefix-xxxxx.pdf.
-#' @param time A numeric vector of time used to label the strata. For example,
-#' this could be julian week for data stratified at a weekly level.
-#' @param n1 A numeric vector of the number of marked fish released in each
-#' time stratum.
+#' @template title
+#' @template prefix
+#' @template time
+#' @template n1
 #' @param m2 A numeric vector of the number of marked fish from n1 that are
 #' recaptured in each time stratum. All recaptures take place within the
 #' stratum of release. Use the \code{\link{TimeStratPetersenNonDiagError_fit}}
@@ -68,14 +65,8 @@
 #' @param bad.u2.H.1 A numeric vector with elements belonging to \code{time}.
 #' In some cases, something goes wrong in the stratum, and the number of
 #' hatchery unmarked (but adipose fin clipped) age 1+ fish should be ignored.
-#' @param logitP.cov A numeric matrix for covariates to fit the
-#' logit(catchability).  Default is a single intercept, i.e. all strata have
-#' the same mean logit(catchability).
-#' @param n.chains Number of parallel MCMC chains to fit.
-#' @param n.iter Total number of MCMC iterations in each chain.
-#' @param n.burnin Number of burn-in iterations.
-#' @param n.sims Number of simulated values to keeps for posterior
-#' distribution.
+#' @template logitP.cov
+#' @template mcmc-parms
 #' @param tauU.alpha One of the parameters along with \code{tauU.beta} for the
 #' prior for the variance of the random noise for the smoothing spline.
 #' @param tauU.beta One of the parameters along with \code{tauU.alpha} for the
@@ -101,10 +92,8 @@
 #' produced. Normally the functions will halt at \code{browser()} calls to
 #' allow the user to peek into the internal variables. Not useful except to
 #' package developers.
-#' @param InitialSeed Numeric value used to initialize the random numbers used
-#' in the MCMC iterations.
-#' @param save.output.to.files Should the plots and text output be save to the files
-#' in addition to being stored in the MCMC object?  
+#' @template InitialSeed
+#' @template save.output.to.files  
 #' 
 #' @return An MCMC object with samples from the posterior distribution. A
 #' series of graphs and text file are also created in the working directory.
@@ -116,6 +105,8 @@
 #' ##---- See the vignettes for example on how to use this package.
 #' 
 #' @export TimeStratPetersenDiagErrorWHSteel_fit
+#' @importFrom stats runif var sd
+
 TimeStratPetersenDiagErrorWHSteel_fit <-
   function( title="TSPDE-WHSteel", prefix="TSPDE-WHSteel-", 
            time, n1, m2, u2.W.YoY, u2.W.1, u2.H.1, sampfrac=rep(1,length(u2.W.YoY)), 
@@ -125,22 +116,21 @@ TimeStratPetersenDiagErrorWHSteel_fit <-
            n.chains=3, n.iter=200000, n.burnin=100000, n.sims=2000,
            tauU.alpha=1, tauU.beta=.05, taueU.alpha=1, taueU.beta=.05, 
            prior.beta.logitP.mean = c(logit(sum(m2,na.rm=TRUE)/sum(n1,na.rm=TRUE)),rep(0,  ncol(as.matrix(logitP.cov))-1)),
-           prior.beta.logitP.sd   = c(sd(logit((m2+.5)/(n1+1)),na.rm=TRUE),        rep(10, ncol(as.matrix(logitP.cov))-1)), 
+           prior.beta.logitP.sd   = c(stats::sd(logit((m2+.5)/(n1+1)),na.rm=TRUE),        rep(10, ncol(as.matrix(logitP.cov))-1)), 
            tauP.alpha=.001, tauP.beta=.001,
            run.prob=seq(0,1,.1),  # what percentiles of run timing are wanted 
            debug=FALSE, debug2=FALSE,
-           InitialSeed=ceiling(runif(1,min=0, 1000000)),
+           InitialSeed=ceiling(stats::runif(1,min=0, 1000000)),
            save.output.to.files=TRUE) {
 # Fit a Time Stratified Petersen model with diagonal entries and with smoothing on U allowing for random error,
 # covariates for the the capture probabilities, and separating the wild vs hatchery fish for STEELHEAD releases
 # The steelhead are nice because 100% of hatchery fish are adipose fin clipped and no wild fish are adipose fin clipped
 # The "diagonal entries" implies that no marked fish are recaptured outside the (time) stratum of release
 #
-   version <- '2021-01-01'
+   version <- '2021-11-01'
    options(width=200)
 
 # Input parameters are
-#    title - title for the analysis
 #    prefix - prefix used for files created with the analysis results
 #             this should be in standard Window's format, eg. JC-2002-ST-TSPDE
 #             to which is appended various suffixes for plots etc
@@ -186,7 +176,7 @@ sampfrac  <- as.vector(sampfrac)
 
 #  Do some basic error checking
 #  1. Check that length of n1, m2, u2, sampfrac, time all match
-if(var(c(length(n1),length(m2),length(u2.W.YoY),length(u2.W.1),length(u2.H.1), length(sampfrac),length(time)))>0){
+if(stats::var(c(length(n1),length(m2),length(u2.W.YoY),length(u2.W.1),length(u2.H.1), length(sampfrac),length(time)))>0){
    cat("***** ERROR ***** Lengths of n1, m2, u2.W.YoY, u2.W.1, u2.H.1, sampfrac, time must all be equal. They are:",
         length(n1)," ",length(m2)," ",length(u2.W.YoY)," ",length(u2.W.1)," ",length(u2.H.1)," ", length(sampfrac)," ",length(time),"\n")
    return()}
